@@ -38,8 +38,7 @@ def mp_cal_performance(tuple_data):
     manager_list.append((ii,result))
 
 
-def get_result_df(py_filename, output_folder, start_date, end_date, para_dict):
-
+def get_result_df(py_filename, output_folder, start_date, end_date, para_dict, number_of_core=8):
     para_key_list = list(para_dict)
     para_list = list(para_dict.values())
     result_df = pd.DataFrame(list(itertools.product(*para_list)), columns=para_key_list)
@@ -51,7 +50,7 @@ def get_result_df(py_filename, output_folder, start_date, end_date, para_dict):
         save_path = generate_filepath(py_filename, output_folder, start_date, end_date, para_dict, result_df.iloc[ii])
         cal_performance_list.append((save_path, start_date, end_date, manager_list, ii))
 
-    pool = mp.Pool(processes=32)
+    pool = mp.Pool(processes=number_of_core)
     pool.map(mp_cal_performance, cal_performance_list)
     pool.close()
 
@@ -61,6 +60,7 @@ def get_result_df(py_filename, output_folder, start_date, end_date, para_dict):
         for key, value in sub_dict.items():
             if key not in result_df.columns:
                 result_df[key] = np.NaN
+                result_df[key] = result_df[key].astype(str)
             result_df.at[ii,key] = value
 
     return result_df
@@ -199,11 +199,22 @@ def cal_performance(save_path, start_date, end_date):
         except:
             result_dict[str(y)] = 0
 
-    result_dict['return_to_bah'] = return_on_capital / bah_return
+
+    result_dict['return_to_bah'] = return_on_capital - bah_return
+
 
     # Singal Win Rate By Year
+    df_all_year = pd.DataFrame()
+    df_signal = df.copy()
+    df_all_year['date'] = df_signal['date']
+    df_all_year['year'] = pd.DatetimeIndex(df_signal['date']).year
+    df_all_year['action'] = df_signal['action']
+    df_all_year['realized_pnl'] = df_signal['realized_pnl']
+    df_all_year = df_all_year[df_all_year['action'].notnull()].reset_index(drop=True)
+    df_all_year['realized_pnl'] = df_all_year['realized_pnl'].shift(-1)
+
     for current_year in year_list:
-        df_year = df.copy()
+        df_year = df_all_year.copy()
         df_year['year'] = pd.DatetimeIndex(df_year['date']).year
         df_year = df_year.loc[df_year['year'] == current_year]
 
@@ -214,6 +225,9 @@ def cal_performance(save_path, start_date, end_date):
         num_of_loss = len(df_year[df_year['realized_pnl'] < 0])
         num_of_win = num_of_trade - num_of_loss
 
+        # print(current_year,num_of_trade,num_of_win,num_of_loss,df_year)
+        #print(df_year)
+
         win_rate = str(int(round(100 * num_of_win / num_of_trade, 0))) if num_of_trade > 0 else '--'
 
         result_dict[f'{current_year}_win_rate'] = win_rate
