@@ -18,10 +18,10 @@ class Components:
                    placeholder="Select Sorting Method",
                    value='Top 20 Net Profit',
                    options=[{'label': 'Top 20 Net Profit', 'value': 'Top 20 Net Profit'},
-                            {'label': 'Top 20 Return/BaH Ratio', 'value': 'Top 20 Return to BaH Ratio'},
+                            {'label': 'Top 20 Return/BaH % Difference', 'value': 'Top 20 Return to BaH Ratio'},
                             {'label': 'Top 20 Net Profit/MDD Ratio', 'value': 'Top 20 Net Profit to MDD'}, ],
                    style={'border-radius': '5px',   'font-size': '12px', }),
-        style={'padding-left': '12.5px', 'width': '240px'})
+        style={'padding-left': '15px', 'width': '235px'})
 
 
     filter_dropdown = html.Div(id='filter_dropdown',
@@ -29,8 +29,8 @@ class Components:
                                                    placeholder="Select Filter",
                                                    options=[
                                                        {'label': 'Exclude Stock', 'value': 'exclude'},
-                                                       {'label': 'Return/BaH Ratio >', 'value': 'return_to_bah>'},
-                                                       {'label': 'Return/BaH Ratio <', 'value': 'return_to_bah<'},
+                                                       {'label': 'Return/BaH % Diff. >', 'value': 'return_to_bah>'},
+                                                       {'label': 'Return/BaH % Diff. <', 'value': 'return_to_bah<'},
                                                        {'label': 'Sharp Ratio >', 'value': 'annualized_sr>'},
                                                        {'label': 'Sharp Ratio <', 'value': 'annualized_sr<'},
                                                        {'label': 'MDD Percentage >', 'value': 'mdd_pct>'},
@@ -43,7 +43,7 @@ class Components:
                                                        {'label': 'Win Rate <', 'value': 'win_rate<'},
                                                    ],
                                                    style={'border-radius': '5px', 'font-size': '12px'}),
-                               style={'padding-left': '15px', 'width': '180px'})
+                               style={'padding-left': '15px', 'width': '175px'})
 
     filter_dropdown_disabled = html.Div(id='filter_dropdown',
                                         children=dbc.Select(id='filter_name', disabled=True,
@@ -84,40 +84,40 @@ class Components:
         # find the unique values from result_df according to the key from para_dict
         checkbox_values = {}
         for key in para_dict:
-            if not key == 'code':
-                unique_values = list(dict.fromkeys(result_df[key].tolist()))
-                try:
-                    unique_values.sort()
-                except:
-                    pass
-                checkbox_values[key] = unique_values
+            # if not key == 'code':
+            unique_values = list(dict.fromkeys(result_df[key].tolist()))
+            try:
+                unique_values.sort()
+            except:
+                pass
+            checkbox_values[key] = unique_values
 
         checkbox_div = []
         for i, para_name in enumerate (para_dict):
-            if not para_name == 'code':
-                _options = checkbox_values[para_name]
-                if _options == [False, True]:
-                    _checklist = dcc.Checklist([str(tf) for tf in _options], [str(tf) for tf in _options], inline=True,
-                                               id={'type': 'para-checklist', 'index': i},
-                                               labelStyle={},
-                                               inputStyle={'margin-left': '10px', 'margin-right': '3px'})
-                else:
-                    _checklist = dcc.Checklist(_options, _options, inline=True,
-                                               id={'type': 'para-checklist', 'index': i},
-                                               labelStyle={'font-size': '12px'},
-                                               #label_checked_style={"color": "red"},
-                                               inputStyle={'margin-left': '10px', 'margin-right': '3px','background-color':'red',
-                                                           'vertical-align':'middle','position':'relative',
-                                                           'bottom':'.15em'})
-                row = html.Div(
-                    dbc.Row([
-                        html.Div(para_name),
-                        html.Div(style={'height': '5px'}),
-                        html.Div(_checklist),
-                        html.Div(style={'height': '5px'}),
-                    ]), style={'padding': '0px 20px', 'font-size': '12px'})
+            # if not para_name == 'code':
+            _options = checkbox_values[para_name]
+            if _options == [False, True]:
+                _checklist = dcc.Checklist([str(tf) for tf in _options], [str(tf) for tf in _options], inline=True,
+                                           id={'type': 'para-checklist', 'index': i},
+                                           labelStyle={},
+                                           inputStyle={'margin-left': '10px', 'margin-right': '3px'})
+            else:
+                _checklist = dcc.Checklist(_options, _options, inline=True,
+                                           id={'type': 'para-checklist', 'index': i},
+                                           labelStyle={'font-size': '12px'},
+                                           #label_checked_style={"color": "red"},
+                                           inputStyle={'margin-left': '10px', 'margin-right': '3px','background-color':'red',
+                                                       'vertical-align':'middle','position':'relative',
+                                                       'bottom':'.15em'})
+            row = html.Div(
+                dbc.Row([
+                    html.Div(para_name),
+                    html.Div(style={'height': '5px'}),
+                    html.Div(_checklist),
+                    html.Div(style={'height': '5px'}),
+                ]), style={'padding': '0px 20px', 'font-size': '12px'})
 
-                checkbox_div.append(row)
+            checkbox_div.append(row)
 
         return checkbox_div
 
@@ -234,11 +234,11 @@ class Components:
             df['mdd_pct'] = "{:.0%}".format(df['mdd_pct'] / 100)
             df['return_on_capital'] = "{:.0%}".format(df['return_on_capital'] / 100)
             df['annualized_return'] = "{:.0%}".format(df['annualized_return'] / 100)
-            df['annualized_std'] = "{:.2%}".format(df['annualized_std'] / 100)
+            df['annualized_std'] = "{:.0%}".format(df['annualized_std'] / 100)
 
             df['cov'] = round(df['cov'], 2)
             df['win_rate'] = "{:.0%}".format(df['win_rate'] / 100)
-            df['return_to_bah'] = round(df['return_to_bah'], 2)
+            df['return_to_bah'] = "{:.0%}".format(df['return_to_bah'] / 100)
 
             df['bah_mdd_dollar'] = "{:,}".format(int(round(df['bah_mdd_dollar'], 0)))
             df['bah_mdd_pct'] = "{:.0%}".format(df['bah_mdd_pct'] / 100)
@@ -246,13 +246,13 @@ class Components:
             df['bah_annualized_return'] = "{:.0%}".format(df['bah_annualized_return'] / 100)
             df['bah_annualized_std'] = "{:.2%}".format(df['bah_annualized_std'] / 100)
         except Exception as e:
-            print(e)
+            # print(e)
             pass
 
         per_col_1_1.append(html.Div('Number of Trade'))
         per_col_1_1.append(html.Div('Net Profit'))
         per_col_1_1.append(html.Div('Net Profit/MDD Ratio'))
-        per_col_1_1.append(html.Div('Return/BaH Ratio'))
+        per_col_1_1.append(html.Div('Return/BaH % Diff.'))
         per_col_1_1.append(html.Div('Win Rate'))
         per_col_1_1.append(html.Div('COV'))
         per_col_1_1.append(html.Div('Total Commission'))
@@ -313,8 +313,35 @@ class Components:
         matrix_div = html.Div([
             html.Div(style={'height': '8px', }),
 
-            html.Div('Selected', style={'color': 'Cyan', 'font-size': '15px'}),
+            dbc.Row([
+                dbc.Col(html.Div('Selected', style={'color': 'Cyan', 'font-size': '15px'}), width=4),
+                # dbc.Col(html.Div('Save', id='save',
+                #                  style={'font-size': '15px','cursor': 'pointer',
+                #                         'text-align': 'center', 'border-radius': '5px',
+                #                         'background-color': 'Yellow', 'color':'black',
+                #                         }), width=4),
+                # dbc.Col(html.Div('List All', id="open",
+                #                  style={'font-size': '15px','cursor': 'pointer',
+                #                         'text-align': 'center', 'border-radius': '5px',
+                #                         'background-color': 'Yellow', 'color':'black',
+                #                         }), width=4),
+            ], style={'padding-right': '20px'}),
+
+            dbc.Modal(
+                [
+                    # dbc.ModalHeader("HEADER"),
+                    dbc.ModalBody("List of Saved Strategies here"),
+                    dbc.ModalBody(html.Div('Close', id="close", style={'font-size': '15px', 'cursor': 'pointer'})),
+
+                    # dbc.ModalFooter(
+                    #     dbc.Button("CLOSE BUTTON", id="close", className="ml-auto")
+                    # ),
+                ],
+                id="modal",
+            ),
+
             dbc.Row(html.Div(title), style={'font-size': '11px'}),
+
             html.Div(style={'height': '15px', }),
 
             html.Div('Performance', style={'color': 'Cyan', 'font-size': '15px'}),
@@ -350,7 +377,7 @@ class Components:
             'mdd_pct':'MDD Percentage',
             'cov':'COV',
             'win_rate':'Win Rate',
-            'return_to_bah': 'Return to BnH Ratio',
+            'return_to_bah': 'Return/BnH % Diff.',
             'exclude': 'Exclude',
         }
     def update_filter_div(self, filter_list):
@@ -412,7 +439,7 @@ class Components:
     def generate_chart_1(self, graph_df, para_key_list, generate_filepath, filename, output_folder, start_date, end_date,
                    para_dict):
         fig_line = px.line()
-        fig_line.update_layout(title = {'text': 'Equity Curves'})
+        fig_line.update_layout(title = {'text': filename})
         fig_line.update_xaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
         fig_line.update_yaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
         fig_line.update_layout(plot_bgcolor=self.chart_bg, paper_bgcolor=self.chart_bg, height=500,
@@ -430,7 +457,7 @@ class Components:
                 hovertemplate = hovertemplate + \
                                 key + " : " + str(graph_df.iloc[i][key]) + "<br>"
             hovertemplate = hovertemplate + "<br>"
-            hovertemplate = hovertemplate + "Return to BaH Ratio : " + str(
+            hovertemplate = hovertemplate + "Return/BaH % Diff. : " + str(
                 round(graph_df.iloc[i]['return_to_bah'], 2)) + "<br>"
             hovertemplate = hovertemplate + "Net Profit to MDD: " + str(
                 round(graph_df.iloc[i]['net_profit_to_mdd'], 2)) + "<br>"
