@@ -1,6 +1,8 @@
 from dash import Dash, dcc, html, Input, Output, State, ALL
 from .components import *
 
+import os
+
 class Plot:
     # Settings
     chart_bg = '#1f2c56'
@@ -32,6 +34,7 @@ class Plot:
         performance_matrix = components.update_performance_matrix(start_date, end_date, df_col.iloc[0].copy(), para_dict)
         filter_div = components.update_filter_div([])
 
+
         sort_method_dropdown  = components.sort_method_dropdown
         filter_dropdown = components.filter_dropdown
         filter_dropdown_disabled = components.filter_dropdown_disabled
@@ -41,6 +44,7 @@ class Plot:
         add_button_style_disabled = components.add_button_style_disabled
 
 
+
         app = Dash(__name__, external_stylesheets=[dbc.themes.SUPERHERO], suppress_callback_exceptions=True)
 
         app.layout = html.Div([
@@ -49,15 +53,20 @@ class Plot:
                 dbc.Row([
                     # Left Column
                     dbc.Col(html.Div([
+                        html.Div(style={'height': '15px', }),
+                        html.Div('Sorting Method', style={'color': 'Cyan', 'margin-left': '15px', 'font-size': '15px'}),
                         html.Div(style={'height': '10px', }),
                         sort_method_dropdown,
-                        html.Div(style={'height': '10px', }),
+                        html.Div(style={'height': '15px', }),
+                        html.Div('Parameters', style={'color': 'Cyan', 'margin-left': '15px', 'font-size': '15px'}),
                         html.Div(id='checklist-container',children=checkbox_div),
-                        html.Div('--------------------------------------',style={'margin-left': '15px'}),
-                        html.Div('Filters for:', style={'font-size': '14px', 'margin-left': '12px'}),
+                        html.Div(style={'height': '10px', }),
+                        # html.Div('--------------------------------------',style={'margin-left': '15px'}),
+                        # html.Div('Filters for:', style={'font-size': '15px', 'margin-left': '15px'}),
+                        html.Div('Filters for', style={'color': 'Cyan', 'margin-left': '15px', 'font-size': '15px'}),
                         html.Div(style={'height': '10px', }),
                         html.Div(id='filter', children=filter_div,style={'padding': '0px 20px',
-                                                                         'padding-right': '30px',
+                                                                         'padding-right': '10px',
                                                                          'font-size': '12px'}),
                         dbc.Row([
                             dbc.Col(id='filter_dropdown_div',children=filter_dropdown,width=8),
@@ -69,7 +78,7 @@ class Plot:
 
                     ],style={'padding':'0px','border-radius':'5px','height': '704px',
                              'background-color':'rgba(0, 0, 0, 0)'})
-                        ,style={'padding':'0',}, width=2),
+                        ,style={'padding':'0','padding-left':'5px'}, width=2),
 
                     # Middle Column
                     dbc.Col(html.Div([
@@ -140,7 +149,6 @@ class Plot:
                            _add_button_style,filter_name,filter_input_value,\
                            hist_area,hist_style, *vals):
 
-
             chart1_button_text = ''
             chart2_button_text = ''
 
@@ -295,20 +303,21 @@ class Plot:
 
                 current_df = current_df.reset_index(drop=True)
 
+
                 para_key_list = list(para_dict)
+
                 if len(para_checklist) > 0:
                     and_list = []
                     for i in range(len(para_key_list)):
                         key = para_key_list[i]
-                        if not key == 'code':
-                            or_list = []
-                            for element in para_checklist[i-1]: # -1 becaause code / para_dict index
-                                if element == 'True':element = True
-                                elif element == 'False':element = False
-                                _list = current_df[key] == element
-                                or_list.append(_list)
-                            or_list = np.logical_or.reduce(or_list)
-                            and_list.append(or_list)
+                        or_list = []
+                        for element in para_checklist[i]: # -1 because code / para_dict index
+                            if element == 'True':element = True
+                            elif element == 'False':element = False
+                            _list = current_df[key] == element
+                            or_list.append(_list)
+                        or_list = np.logical_or.reduce(or_list)
+                        and_list.append(or_list)
                     and_list = np.logical_and.reduce(and_list)
                     df_checked = current_df.loc[pd.DataFrame(and_list, columns=['check'])['check']].reset_index(
                         drop=True).copy()
@@ -333,6 +342,7 @@ class Plot:
 
 
 
+        # Click on Chart 1 line
         @app.callback(
             Output(component_id='performance_matrix', component_property='children'),
             Output('chart2_button', 'style'),
@@ -351,4 +361,46 @@ class Plot:
             return performance_matrix, button_style
 
 
+        # Model
+        @app.callback(
+            Output("modal", "is_open"),
+            [Input("open", "n_clicks"), Input("close", "n_clicks")],
+            [State("modal", "is_open")],
+        )
+        def toggle_modal(n1, n2, is_open):
+            # print('Modal!')
+            if n1 or n2:
+                return not is_open
+            else:
+                pass
+                # print('No Modal Click')
+            return is_open
+
+        # Save Button
+        # @app.callback(
+        #     Output('save', "style"),
+        #     Input('save', "n_clicks"),
+        #     State('save', "style"),
+        # )
+        # def save(save_click, save_style):
+        #     print(output_folder)
+        #     # print('Saved!')
+        #     if not os.path.isfile('saved_strategies.csv'):
+        #         print('No File!!!!')
+        #         saved_df = pd.DataFrame(columns=['parameters','start_date','end_date' ])
+        #         print(saved_df)
+        #
+        #     else:
+        #         pass
+        #         print('File Here !!!')
+        #     if save_click:
+        #         pass
+        #         # print(save_click)
+        #     else:
+        #         pass
+        #         # print('No Save Click')
+        #
+        #     return save_style
+
+
         return app
\ No newline at end of file
